/**
 * File:
 *  main.c
 *
 * Notes:
 *  Application entry point, sets-up hardware
 *
  * Ports B, C & D:
 *      SW3: 2, 3 and 4 ON
 *
 * Turn on LCD backlight:
 *      SW4: 6 On
 *
 * Notes:
 *  To control the speed of fade, change the settings of
 *     FADE_CYCLE_REPEATS and FADE_DELTA
 *
 * History:
 *  09/09/2012 Written by Simon Platten
 */
#include "fader.h"

// Constants
#define NUMBER_OF_REPEATS  0
#define TOTAL_FADERS       2

static volatile faderDef aryFaders[TOTAL_FADERS];
/**
 * Interrupt handler
 */
void interrupt() {
  if ( TMR0IF_bit ) {
    serviceFaders();
    TMR0H = 0xFF;    // preset for Timer0 MSB register
    TMR0L = 0x38;    // preset for Timer0 LSB register
    TMR0IF_bit = 0;
  }
}
/**
 * Entry point
 */
void main() {
  ANSELB = 0;                    // Configure PORTB pins as digital
  ANSELC = 0;                    // Configure PORTC pins as digital
  ANSELD = 0;                    // Configure PORTD pins as digital
  ANSELE = 0;                    // Configure PORTD pins as digital
  TRISB = 0;                     // Configure PORTB as output
  TRISC = 0;                     // Configure PORTC as output
  TRISD = 0;                     // Configure PORTD as output
  TRISE = 0x0f;                  // Configure PORTE as input
  LATB = 0;                      // Clear PORTC
  LATC = 0;                      // Clear PORTC
  LATD = 0;                      // Clear PORTD
// Create and initialise faders
  initFader(&aryFaders[0], &LATC, MULTIPLE_FADERS, 0x55, FADE_IN, TRUE, TRUE, TRUE,
            3, NUMBER_OF_REPEATS);
  initFader(&aryFaders[1], &LATD, MULTIPLE_FADERS, 0xaa, FADE_IN, TRUE, TRUE, TRUE,
            5, NUMBER_OF_REPEATS);
// Timer0 Registers:
// 16-Bit Mode; Prescaler=1:1
// TMRH Preset=FF
// TMRL Preset=38
// Freq=10,000.00Hz
// Period=100,000 ns
  T0CON.TMR0ON = 1;// Timer0 On/Off Control bit:1=Enables Timer0 / 0=Stops Timer0
  T0CON.T08BIT = 0;// Timer0 8-bit/16-bit Control bit: 1=8-bit timer/counter / 0=16-bit timer/counter
  T0CON.T0CS   = 0;// TMR0 Clock Source Select bit: 0=Internal Clock (CLKO) / 1=Transition on T0CKI pin
  T0CON.T0SE   = 0;// TMR0 Source Edge Select bit: 0=low/high / 1=high/low
  T0CON.PSA    = 1;// Prescaler Assignment bit: 0=Prescaler is assigned; 1=NOT assigned/bypassed
  T0CON.T0PS2  = 0;// bits 2-0  PS2:PS0: Prescaler Select bits
  T0CON.T0PS1  = 0;
  T0CON.T0PS0  = 0;
  TMR0H = 0xFF;    // preset for Timer0 MSB register
  TMR0L = 0x38;    // preset for Timer0 LSB register
  TMR0IE_bit = 1;
// Global interrupt enable
  GIE_bit = 1;
// Endless loop
  while (1) {
  }
}